joop.web — joop 0.0.1 documentation

# joop.web

Web module.

All functionality related to web-backends, HTML templating, etc. lives here.

Modules:

  component: Define web UI or API components. html: Where components get rendered to HTML. view: Register components to webservers, set up views routes, etc.

Modules

`component` | Components are programmatic representations of data or UI elements, designed to be rendered dynamically,
`components` | Useful components for web development. It includes a base class AlpineTableComponent for generating AlpineJS-powered tables based on Pydantic or SQLModel models. The module also defines data access object (DAO) classes for handling row data.
`html` | An HTML Component is a joop Component that renders to HTML.
`j_env` | Environment management module for joop.
`templater` | Templating environment factory for joop.
`view` | Views are how components are integrated with webservers. The view (or route) is defined